@@ -23,6 +23,10 @@
 
 #ifndef emit
 #define emit Q_EMIT
+#include <private/qcombobox_p.h>
+#undef emit
+#else
+#include <private/qcombobox_p.h>
 #endif
 #include <private/qcombobox_p.h>
 
@@ -36,14 +40,16 @@ enum layoutMargin
 };
 
 /*!
- * \~chinese \class DSearchComboBox
- * \~chinese \brief DSearchComboBox一个聚合 QComboBox 搜索控件
- * \~chinese \li DSearchComboBox提供了在下拉列表中搜索功能
- * \~chinese \li DSearchComboBox该控件适用于在大段列表中快速查找
+  \class Dtk::Widget::DSearchComboBox
+  \inmodule dtkwidget
+  \brief DSearchComboBox一个聚合 QComboBox 搜索控件.
+
+  DSearchComboBox提供了在下拉列表中搜索功能
+  DSearchComboBox该控件适用于在大段列表中快速查找
+  \image DSearchComboBox.png
  */
 DSearchComboBox::DSearchComboBox(QWidget *parent)
-    : DComboBox(parent)
-    , DObject(*new DSearchComboBoxPrivate(this))
+    : DComboBox(*new DSearchComboBoxPrivate(this), parent)
 {
 }
 
@@ -62,8 +68,7 @@ void DSearchComboBox::showPopup()
 {
     Q_D(DSearchComboBox);
     QComboBoxPrivate *dd = reinterpret_cast<QComboBoxPrivate *>(qGetPtrHelper(d_ptr));
-    QComboBox::showPopup();
-
+    DComboBox::showPopup();
     if(auto layout = static_cast<QBoxLayout*>(dd->container->layout())) {
         if (!isEditable() && !d->searchEdit) {
             //因为dd->container容器在QComboBox::showPopup()
@@ -77,7 +82,8 @@ void DSearchComboBox::showPopup()
             layout->setSpacing(0);
             searlayout->addWidget(d->searchEdit);
             layout->insertLayout(0, searlayout);
-
+            dd->container->setFixedHeight(dd->container->height() + d->searchEdit->height() +
+                                          layout->spacing() + layout->margin() + layoutMargin);
             d->proxyModel = new QSortFilterProxyModel(this);
             d->proxyModel->setSourceModel(model());
 
@@ -104,7 +110,7 @@ void DSearchComboBox::showPopup()
 }
 
 DSearchComboBoxPrivate::DSearchComboBoxPrivate(DSearchComboBox *q)
-    : DObjectPrivate(q)
+    : DComboBoxPrivate (q)
     , searchEdit(nullptr)
     , completer(nullptr)
     , proxyModel(nullptr)
